@@ -5,13 +5,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': 'python3.6 ./Parser/asdl_c.py',
- 'ASDLGEN_FILES': './Parser/asdl.py ./Parser/asdl_c.py',
- 'AST_ASDL': './Parser/Python.asdl',
- 'AST_C': 'Python/Python-ast.c',
- 'AST_C_DIR': 'Python',
- 'AST_H': 'Include/Python-ast.h',
- 'AST_H_DIR': 'Include',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
@@ -22,42 +15,41 @@ build_time_vars = {'ABIFLAGS': 'm',
               '-Wl,-O1,--sort-common,--as-needed,-z,relro',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'armv5tel-unknown-linux-gnueabi',
+ 'BUILD_GNU_TYPE': 'armv7l-unknown-linux-gnueabi',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
            '-Wstrict-prototypes -march=armv5te -O2 -pipe '
-           '-fstack-protector-strong --param=ssp-buffer-size=4 -march=armv5te '
-           '-O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4 '
-           '-march=armv5te -O2 -pipe -fstack-protector-strong '
-           '--param=ssp-buffer-size=4',
+           '-fstack-protector-strong -fno-plt -march=armv5te -O2 -pipe '
+           '-fstack-protector-strong -fno-plt -march=armv5te -O2 -pipe '
+           '-fstack-protector-strong -fno-plt',
  'CFLAGSFORSHARED': '-fPIC',
+ 'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-march=armv5te -O2 -pipe -fstack-protector-strong '
-                     '--param=ssp-buffer-size=4',
+                     '-fno-plt',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers',
  'CONFIGURE_CPPFLAGS': '-D_FORTIFY_SOURCE=2',
  'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro',
  'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-threads' "
-                "'--with-computed-gotos' '--enable-optimizations' "
-                "'--without-lto' '--enable-ipv6' '--with-system-expat' "
-                "'--with-dbmliborder=gdbm:ndbm' '--with-system-ffi' "
-                "'--with-system-libmpdec' "
+                "'--with-computed-gotos' '--without-lto' '--enable-ipv6' "
+                "'--with-system-expat' '--with-dbmliborder=gdbm:ndbm' "
+                "'--with-system-ffi' '--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'CFLAGS=-march=armv5te -O2 -pipe -fstack-protector-strong "
-                "--param=ssp-buffer-size=4' "
+                "-fno-plt' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro' "
                 "'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.6m',
  'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/build/python/src/Python-3.6.1/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.6.1/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.6.4/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.6.4/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
@@ -98,9 +90,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'GITTAG': '',
  'GITVERSION': '',
  'GNULD': 'yes',
- 'GRAMMAR_C': 'Python/graminit.c',
- 'GRAMMAR_H': 'Include/graminit.h',
- 'GRAMMAR_INPUT': './Grammar/Grammar',
  'HAVE_ACCEPT4': 1,
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
@@ -136,10 +125,18 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_COPYSIGN': 1,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 0,
+ 'HAVE_CURSES_FILTER': 1,
  'HAVE_CURSES_H': 1,
+ 'HAVE_CURSES_HAS_KEY': 1,
+ 'HAVE_CURSES_IMMEDOK': 1,
+ 'HAVE_CURSES_IS_PAD': 1,
  'HAVE_CURSES_IS_TERM_RESIZED': 1,
  'HAVE_CURSES_RESIZETERM': 1,
  'HAVE_CURSES_RESIZE_TERM': 1,
+ 'HAVE_CURSES_SYNCOK': 1,
+ 'HAVE_CURSES_TYPEAHEAD': 1,
+ 'HAVE_CURSES_USE_ENV': 1,
+ 'HAVE_CURSES_WCHGAT': 1,
  'HAVE_DECL_ISFINITE': 1,
  'HAVE_DECL_ISINF': 1,
  'HAVE_DECL_ISNAN': 1,
@@ -433,6 +430,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SYS_STATVFS_H': 1,
  'HAVE_SYS_STAT_H': 1,
  'HAVE_SYS_SYSCALL_H': 1,
+ 'HAVE_SYS_SYSMACROS_H': 1,
  'HAVE_SYS_SYS_DOMAIN_H': 0,
  'HAVE_SYS_TERMIO_H': 0,
  'HAVE_SYS_TIMES_H': 1,
@@ -480,7 +478,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'armv5tel-unknown-linux-gnueabi',
+ 'HOST_GNU_TYPE': 'armv7l-unknown-linux-gnueabi',
  'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.6m '
                    '/usr/include/python3.6m',
  'INCLUDEDIR': '/usr/include',
@@ -559,14 +557,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPCODETARGETGEN': '\\',
- 'OPCODETARGETGEN_FILES': '\\',
- 'OPCODETARGETS_H': '\\',
- 'OPCODE_H': './Include/opcode.h',
- 'OPCODE_H_DIR': './Include',
- 'OPCODE_H_GEN': 'python3.6 ./Tools/scripts/generate_opcode_h.py '
-                 './Lib/opcode.py ./Include/opcode.h',
- 'OPCODE_H_SCRIPT': './Tools/scripts/generate_opcode_h.py',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -597,24 +587,22 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': ':',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_GEN': 'python3.6',
+ 'PYTHON_FOR_REGEN': 'python3.6',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
               '-Wstrict-prototypes -march=armv5te -O2 -pipe '
-              '-fstack-protector-strong --param=ssp-buffer-size=4 '
-              '-march=armv5te -O2 -pipe -fstack-protector-strong '
-              '--param=ssp-buffer-size=4 -march=armv5te -O2 -pipe '
-              '-fstack-protector-strong --param=ssp-buffer-size=4',
+              '-fstack-protector-strong -fno-plt -march=armv5te -O2 -pipe '
+              '-fstack-protector-strong -fno-plt -march=armv5te -O2 -pipe '
+              '-fstack-protector-strong -fno-plt',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers',
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -Wstrict-prototypes -march=armv5te -O2 -pipe '
-                   '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                   '-march=armv5te -O2 -pipe -fstack-protector-strong '
-                   '--param=ssp-buffer-size=4 -march=armv5te -O2 -pipe '
-                   '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                   '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
+                   '-fstack-protector-strong -fno-plt -march=armv5te -O2 -pipe '
+                   '-fstack-protector-strong -fno-plt -march=armv5te -O2 -pipe '
+                   '-fstack-protector-strong -fno-plt -std=c99 -Wextra '
+                   '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -I. -I./Include '
                    '-D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2 -fPIC '
                    '-DPy_BUILD_CORE',
@@ -630,7 +618,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.1',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.4',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -657,7 +645,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-36m-arm-linux-gnueabi',
- 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
+ 'SRCDIRS': 'Parser Objects Python Modules Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -671,9 +659,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.1 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.4 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.1 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.4 ./python '
                './Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'THREADOBJ': 'Python/thread.o',
@@ -682,6 +670,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TM_IN_SYS_TIME': 0,
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
+ 'UPDATE_FILE': 'python3.6 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'USE_INLINE': 1,
  'VERSION': '3.6',
@@ -697,8 +686,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.6.1',
- 'abs_srcdir': '/build/python/src/Python-3.6.1',
+ 'abs_builddir': '/build/python/src/Python-3.6.4',
+ 'abs_srcdir': '/build/python/src/Python-3.6.4',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
